@@ -243,11 +243,11 @@ class SqreamDialect(DefaultDialect):
         # return __import__("sqream_dbapi", fromlist="sqream")
 
         try:
-            from pysqream import dbapi as dbapi
+            from pysqream import pysqream as pysqream
         except ImportError:
-            import dbapi
+            import pysqream
 
-        return dbapi
+        return pysqream
 
     def initialize(self, connection):
         self.default_schema_name = 'public'
@@ -266,15 +266,12 @@ class SqreamDialect(DefaultDialect):
 
         query = "select get_schemas()"
         return [schema for schema, database in connection.execute(query).fetchall()]
-        
 
     def get_view_names(self, connection, schema='public', **kw):
         
         # 0,public.fuzz
         return [schema_view.split(".", 1)[1] for idx, schema_view in connection.execute("select get_views()").fetchall() if schema_view.split(".", 1)[0] == schema]
 
-
-
     def has_table(self, connection, table_name, schema=None):
         return table_name in self.get_table_names(connection, schema)
 
